@@ -30,9 +30,9 @@ const cl_DF fround (const cl_DF& x)
             { return x; }
             else
             if (uexp > DF_exp_mid+1) // e>1 ?
-              { var uint64 bitmask = // Bitmaske: Bit 52-e gesetzt, alle anderen gelscht
+              { var uint64 bitmask = // Bitmaske: Bit 52-e gesetzt, alle anderen gelöscht
                   bit(DF_mant_len+DF_exp_mid-uexp);
-                var uint64 mask = // Bitmaske: Bits 51-e..0 gesetzt, alle anderen gelscht
+                var uint64 mask = // Bitmaske: Bits 51-e..0 gesetzt, alle anderen gelöscht
                   bitmask-1;
                 if ( ((x_ & bitmask) ==0) // Bit 52-e =0 -> abrunden
                      || ( ((x_ & mask) ==0) // Bit 52-e =1 und Bits 51-e..0 >0 -> aufrunden
@@ -40,19 +40,19 @@ const cl_DF fround (const cl_DF& x)
                           && ((x_ & (bitmask<<1)) ==0)
                    )    )
                   // abrunden
-                  { mask |= bitmask; // Bitmaske: Bits 52-e..0 gesetzt, alle anderen gelscht
+                  { mask |= bitmask; // Bitmaske: Bits 52-e..0 gesetzt, alle anderen gelöscht
                     return allocate_dfloat( x_ & ~mask );
                   }
                   else
                   // aufrunden
                   { return allocate_dfloat
                       ((x_ | mask) // alle diese Bits 51-e..0 setzen (Bit 52-e schon gesetzt)
-                       + 1 // letzte Stelle erhhen, dabei evtl. Exponenten incrementieren
+                       + 1 // letzte Stelle erhöhen, dabei evtl. Exponenten incrementieren
                       );
                   }
               }
             elif (uexp == DF_exp_mid+1) // e=1 ?
-              // Wie bei 1 < e <= 52, nur da Bit 53-e stets gesetzt ist.
+              // Wie bei 1 < e <= 52, nur daß Bit 53-e stets gesetzt ist.
               { if ((x_ & bit(DF_mant_len-1)) ==0) // Bit 52-e =0 -> abrunden
                   // abrunden
                   { return allocate_dfloat( x_ & ~(bit(DF_mant_len)-1) ); }
@@ -60,13 +60,13 @@ const cl_DF fround (const cl_DF& x)
                   // aufrunden
                   { return allocate_dfloat
                       ((x_ | (bit(DF_mant_len)-1)) // alle diese Bits 52-e..0 setzen
-                       + 1 // letzte Stelle erhhen, dabei evtl. Exponenten incrementieren
+                       + 1 // letzte Stelle erhöhen, dabei evtl. Exponenten incrementieren
                       );
                   }
               }
             else // e=0 ?
-              // Wie bei 1 < e <= 52, nur da Bit 52-e stets gesetzt
-              // und Bit 53-e stets gelscht ist.
+              // Wie bei 1 < e <= 52, nur daß Bit 52-e stets gesetzt
+              // und Bit 53-e stets gelöscht ist.
               { if ((x_ & (bit(DF_mant_len)-1)) ==0)
                   // abrunden von +-0.5 zu 0.0
                   { return cl_DF_0; }
@@ -74,7 +74,7 @@ const cl_DF fround (const cl_DF& x)
                   // aufrunden
                   { return allocate_dfloat
                       ((x_ | (bit(DF_mant_len)-1)) // alle Bits 51-e..0 setzen
-                       + 1 // letzte Stelle erhhen, dabei Exponenten incrementieren
+                       + 1 // letzte Stelle erhöhen, dabei Exponenten incrementieren
                       );
               }   }
         }
@@ -90,9 +90,9 @@ const cl_DF fround (const cl_DF& x)
             else
             if (uexp > DF_exp_mid+1) // e>1 ?
               { if (uexp > DF_exp_mid+DF_mant_len-32) // e > 20 ?
-                  { var uint32 bitmask = // Bitmaske: Bit 52-e gesetzt, alle anderen gelscht
+                  { var uint32 bitmask = // Bitmaske: Bit 52-e gesetzt, alle anderen gelöscht
                       bit(DF_mant_len+DF_exp_mid-uexp);
-                    var uint32 mask = // Bitmaske: Bits 51-e..0 gesetzt, alle anderen gelscht
+                    var uint32 mask = // Bitmaske: Bits 51-e..0 gesetzt, alle anderen gelöscht
                       bitmask-1;
                     if ( ((mlo & bitmask) ==0) // Bit 52-e =0 -> abrunden
                          || ( ((mlo & mask) ==0) // Bit 52-e =1 und Bits 51-e..0 >0 -> aufrunden
@@ -102,21 +102,21 @@ const cl_DF fround (const cl_DF& x)
                                     : ((mlo & (bitmask<<1)) ==0)
                        )    )    )
                       // abrunden
-                      { mask |= bitmask; // Bitmaske: Bits 52-e..0 gesetzt, alle anderen gelscht
+                      { mask |= bitmask; // Bitmaske: Bits 52-e..0 gesetzt, alle anderen gelöscht
                         return allocate_dfloat(semhi, mlo & ~mask );
                       }
                       else
                       // aufrunden
                       { mlo = (mlo | mask) // alle diese Bits 51-e..0 setzen (Bit 52-e schon gesetzt)
-                              + 1; // letzte Stelle erhhen,
+                              + 1; // letzte Stelle erhöhen,
                         if (mlo==0) { semhi += 1; } // dabei evtl. Exponenten incrementieren
                         return allocate_dfloat(semhi,mlo);
                       }
                   }
                   else
-                  { var uint32 bitmask = // Bitmaske: Bit 20-e gesetzt, alle anderen gelscht
+                  { var uint32 bitmask = // Bitmaske: Bit 20-e gesetzt, alle anderen gelöscht
                       bit(DF_mant_len+DF_exp_mid-32-uexp);
-                    var uint32 mask = // Bitmaske: Bits 19-e..0 gesetzt, alle anderen gelscht
+                    var uint32 mask = // Bitmaske: Bits 19-e..0 gesetzt, alle anderen gelöscht
                       bitmask-1;
                     if ( ((semhi & bitmask) ==0) // Bit 52-e =0 -> abrunden
                          || ( (mlo==0) && ((semhi & mask) ==0) // Bit 52-e =1 und Bits 51-e..0 >0 -> aufrunden
@@ -124,21 +124,21 @@ const cl_DF fround (const cl_DF& x)
                               && ((semhi & (bitmask<<1)) ==0)
                        )    )
                       // abrunden
-                      { mask |= bitmask; // Bitmaske: Bits 20-e..0 gesetzt, alle anderen gelscht
+                      { mask |= bitmask; // Bitmaske: Bits 20-e..0 gesetzt, alle anderen gelöscht
                         return allocate_dfloat( semhi & ~mask, 0 );
                       }
                       else
                       // aufrunden
                       { return allocate_dfloat
                           ((semhi | mask) // alle diese Bits 19-e..0 setzen (Bit 20-e schon gesetzt)
-                           + 1, // letzte Stelle erhhen, dabei evtl. Exponenten incrementieren
+                           + 1, // letzte Stelle erhöhen, dabei evtl. Exponenten incrementieren
                            0
                           );
                       }
                   }
               }
             elif (uexp == DF_exp_mid+1) // e=1 ?
-              // Wie bei 1 < e <= 20, nur da Bit 53-e stets gesetzt ist.
+              // Wie bei 1 < e <= 20, nur daß Bit 53-e stets gesetzt ist.
               { if ((semhi & bit(DF_mant_len-32-1)) ==0) // Bit 52-e =0 -> abrunden
                   // abrunden
                   { return allocate_dfloat( semhi & ~(bit(DF_mant_len-32)-1) , 0 ); }
@@ -146,14 +146,14 @@ const cl_DF fround (const cl_DF& x)
                   // aufrunden
                   { return allocate_dfloat
                       ((semhi | (bit(DF_mant_len-32)-1)) // alle diese Bits 52-e..0 setzen
-                       + 1, // letzte Stelle erhhen, dabei evtl. Exponenten incrementieren
+                       + 1, // letzte Stelle erhöhen, dabei evtl. Exponenten incrementieren
                        0
                       );
                   }
               }
             else // e=0 ?
-              // Wie bei 1 < e <= 20, nur da Bit 52-e stets gesetzt
-              // und Bit 53-e stets gelscht ist.
+              // Wie bei 1 < e <= 20, nur daß Bit 52-e stets gesetzt
+              // und Bit 53-e stets gelöscht ist.
               { if ((mlo==0) && ((semhi & (bit(DF_mant_len-32)-1)) ==0))
                   // abrunden von +-0.5 zu 0.0
                   { return cl_DF_0; }
@@ -161,7 +161,7 @@ const cl_DF fround (const cl_DF& x)
                   // aufrunden
                   { return allocate_dfloat
                       ((semhi | (bit(DF_mant_len-32)-1)) // alle Bits 51-e..0 setzen
-                       + 1, // letzte Stelle erhhen, dabei Exponenten incrementieren
+                       + 1, // letzte Stelle erhöhen, dabei Exponenten incrementieren
                        0
                       );
               }   }
