@@ -11,22 +11,20 @@
 
 #include "cl_DF.h"
 
-#undef MAYBE_INLINE
-#define MAYBE_INLINE inline
+#include "cl_inline.h"
 #include "cl_DF_minusp.cc"
 #include "cl_DF_zerop.cc"
 
 namespace cln {
 
-MAYBE_INLINE2
-cl_boolean plusp (const cl_DF& x)
+CL_INLINE2 bool CL_INLINE2_DECL(plusp) (const cl_DF& x)
 {
-	if (minusp(x))
-		return cl_false; // x<0 -> nein
-	elif (zerop(x))
-		return cl_false; // x=0 -> nein
+	if (minusp_inline(x))
+		return false; // x<0 -> nein
+	elif (zerop_inline(x))
+		return false; // x=0 -> nein
 	else
-		return cl_true; // sonst ist x>0.
+		return true; // sonst ist x>0.
 }
 
 }  // namespace cln
