@@ -13,8 +13,7 @@
 
 namespace cln {
 
-MAYBE_INLINE
-uintL float_digits (const cl_DF& x)
+CL_INLINE uintC CL_INLINE_DECL(float_digits) (const cl_DF& x)
 {
 	unused x;
 	return DF_mant_len+1; // 53
