@@ -15,8 +15,7 @@
 #include "cl_low.h"
 #include "cl_ieee.h"
 
-#undef MAYBE_INLINE
-#define MAYBE_INLINE inline
+#include "cl_inline.h"
 #include "cl_FF_zerop.cc"
 
 namespace cln {
@@ -36,20 +35,20 @@ const cl_FF operator/ (const cl_FF& x1, const cl_FF& x2)
 //   nach Rundung mant1/mant2 >=1/2, <=2*mant1<2.
 //   Bei mant1/mant2 >=1 brauche 23 Nachkommabits,
 //   bei mant1/mant2 <1 brauche 24 Nachkommabits.
-//   Frs Runden: brauche ein Rundungsbit (Rest gibt an, ob exakt).
+//   Fürs Runden: brauche ein Rundungsbit (Rest gibt an, ob exakt).
 //   Brauche daher insgesamt 25 Nachkommabits von mant1/mant2.
 //   Dividiere daher (als Unsigned Integers) 2^25*(2^24*mant1) durch (2^24*mant2).
 //   Falls der Quotient >=2^25 ist, runde die letzten zwei Bits weg und
-//     erhhe den Exponenten um 1.
+//     erhöhe den Exponenten um 1.
 //   Falls der Quotient <2^25 ist, runde das letzte Bit weg. Bei rounding
 //     overflow schiebe um ein weiteres Bit nach rechts, incr. Exponenten.
   #if defined(FAST_FLOAT) && !defined(__i386__)
       float_to_FF(FF_to_float(x1) / FF_to_float(x2), return ,
                   TRUE, TRUE, // Overflow und subnormale Zahl abfangen
-                  !zerop(x1), // ein Ergebnis +/- 0.0
+                  !zerop_inline(x1), // ein Ergebnis +/- 0.0
                               // ist genau dann in Wirklichkeit ein Underflow
-                  zerop(x2), // Division durch Null abfangen
-                  FALSE // kein NaN als Ergebnis mglich
+                  zerop_inline(x2), // Division durch Null abfangen
+                  FALSE // kein NaN als Ergebnis möglich
                  );
   #else
       // x1,x2 entpacken:
@@ -59,15 +58,15 @@ const cl_FF operator/ (const cl_FF& x1, const cl_FF& x2)
       var cl_signean sign2;
       var sintL exp2;
       var uintL mant2;
-      FF_decode(x2, { cl_error_division_by_0(); }, sign2=,exp2=,mant2=);
+      FF_decode(x2, { throw division_by_0_exception(); }, sign2=,exp2=,mant2=);
       FF_decode(x1, { return x1; }, sign1=,exp1=,mant1=);
       exp1 = exp1 - exp2; // Differenz der Exponenten
       sign1 = sign1 ^ sign2; // Ergebnis-Vorzeichen
-      // Dividiere 2^25*mant1 durch mant2 oder (quivalent)
-      // 2^i*2^25*mant1 durch 2^i*mant2 fr irgendein i mit 0 <= i <= 32-24 :
+      // Dividiere 2^25*mant1 durch mant2 oder (äquivalent)
+      // 2^i*2^25*mant1 durch 2^i*mant2 für irgendein i mit 0 <= i <= 32-24 :
       var uintL mant;
       var uintL rest;
-      // whle i = 32-(FF_mant_len+1), also i+(FF_mant_len+2) = 33.
+      // wähle i = 32-(FF_mant_len+1), also i+(FF_mant_len+2) = 33.
       divu_6432_3232(mant1<<1,0, mant2<<(32-(FF_mant_len+1)), mant=,rest=);
       if (mant >= bit(FF_mant_len+2))
         // Quotient >=2^25 -> 2 Bits wegrunden
