@@ -11,15 +11,14 @@
 
 #include "cl_LF.h"
 
-#undef MAYBE_INLINE
-#define MAYBE_INLINE inline
+#include "cl_inline.h"
 #include "cl_LF_minusp.cc"
 
 namespace cln {
 
-const cl_LF ffloor (const cl_LF& x)
+CL_INLINE2 const cl_LF CL_INLINE2_DECL(ffloor) (const cl_LF& x)
 {
-	if (minusp(x))
+	if (minusp_inline(x))
 		return futruncate(x);
 	else
 		return ftruncate(x);
