@@ -24,18 +24,18 @@ const cl_LF fround (const cl_LF& x)
 // e>=16n -> Ergebnis x
 #if 0
       var cl_signean sign;
-      var sintL exp;
+      var sintE exp;
       var const uintD* mantMSDptr;
       var uintC mantlen;
       LF_decode(x, { return x; }, sign=,exp=,mantMSDptr=,mantlen=,);
       if (exp<0) { return encode_LF0(mantlen); } // e<0 -> Ergebnis 0.0
-      if ((uintL)exp >= intDsize*(uintL)mantlen) // e>=16n -> x als Ergebnis
+      if ((uintE)exp >= intDsize*mantlen) // e>=16n -> x als Ergebnis
         { return x; }
         else
         // 0 <= e < 16n
         { // alle hinteren 16n-e Bits wegrunden:
-          var uintC count = floor((uintL)exp,intDsize); // zu kopierende Digits, < mantlen
-          var uintC bitcount = ((uintL)exp) % intDsize; // zu kopierende Bits danach, >=0, <intDsize
+          var uintC count = floor((uintE)exp,intDsize); // zu kopierende Digits, < mantlen
+          var uintC bitcount = ((uintE)exp) % intDsize; // zu kopierende Bits danach, >=0, <intDsize
           var uintD mask = minus_bit(intDsize-bitcount-1); // Maske mit bitcount+1 Bits
           var const uintD* mantptr = mantMSDptr mspop count;
           if ((mspref(mantptr,0) & -mask) ==0) goto ab; // Bit 16n-e-1 =0 -> abrunden
@@ -56,7 +56,7 @@ const cl_LF fround (const cl_LF& x)
            {var uintD* ptr =
               copy_loop_msp(mantMSDptr,MSDptr,count); // count ganze Digits kopieren
             msprefnext(ptr) = mspref(mantptr,0) & mask; // dann bitcount Bits kopieren
-            clear_loop_msp(ptr,mantlen-count-1); // Rest mit Nullen fllen
+            clear_loop_msp(ptr,mantlen-count-1); // Rest mit Nullen füllen
             return encode_LF(sign,exp,MSDptr,mantlen);
           }}
           auf: // aufrunden
@@ -67,21 +67,21 @@ const cl_LF fround (const cl_LF& x)
               copy_loop_msp(mantMSDptr,MSDptr,count); // count ganze Digits kopieren
             if ((mspref(ptr,0) = ((mspref(mantptr,0) & mask) - mask)) == 0) // dann bitcount Bits kopieren und incrementieren
               { if (!( inc_loop_lsp(ptr,count) ==0)) // evtl. weiterincrementieren
-                  { mspref(MSDptr,0) = bit(intDsize-1); exp = exp+1; } // evtl. Exponenten erhhen
+                  { mspref(MSDptr,0) = bit(intDsize-1); exp = exp+1; } // evtl. Exponenten erhöhen
               }
-            clear_loop_msp(ptr mspop 1,mantlen-count-1); // Rest mit Nullen fllen
+            clear_loop_msp(ptr mspop 1,mantlen-count-1); // Rest mit Nullen füllen
             return encode_LF(sign,exp,MSDptr,mantlen);
           }}
         }
 #else
       var uintC len = TheLfloat(x)->len;
-      var uintL uexp = TheLfloat(x)->expo;
+      var uintE uexp = TheLfloat(x)->expo;
       if (uexp < LF_exp_mid)
         { if (uexp == 0) { return x; } // x=0.0 -> Ergebnis 0.0
           return encode_LF0(len); // e<0 -> Ergebnis 0.0
         }
-      var uintL exp = uexp - LF_exp_mid;
-      if (exp >= intDsize*(uintL)len) // e>=16n -> x als Ergebnis
+      var uintE exp = uexp - LF_exp_mid;
+      if (exp >= intDsize*len) // e>=16n -> x als Ergebnis
         { return x; }
       // 0 <= e < 16n
       // alle hinteren 16n-e Bits wegrunden:
@@ -113,7 +113,7 @@ const cl_LF fround (const cl_LF& x)
           var uintD* ptr =
             copy_loop_msp(x_mantMSDptr,arrayMSDptr(TheLfloat(y)->data,len),count); // count ganze Digits kopieren
           msprefnext(ptr) = mspref(x_mantMSDptr,count) & mask; // dann bitcount Bits kopieren
-          clear_loop_msp(ptr,len-count-1); // Rest mit Nullen fllen
+          clear_loop_msp(ptr,len-count-1); // Rest mit Nullen füllen
          }
          return y;
         }
@@ -126,9 +126,9 @@ const cl_LF fround (const cl_LF& x)
             copy_loop_msp(x_mantMSDptr,y_mantMSDptr,count); // count ganze Digits kopieren
           if ((mspref(ptr,0) = ((mspref(x_mantMSDptr,count) & mask) - mask)) == 0) // dann bitcount Bits kopieren und incrementieren
             { if (!( inc_loop_lsp(ptr,count) ==0)) // evtl. weiterincrementieren
-                { mspref(y_mantMSDptr,0) = bit(intDsize-1); (TheLfloat(y)->expo)++; } // evtl. Exponenten erhhen
+                { mspref(y_mantMSDptr,0) = bit(intDsize-1); (TheLfloat(y)->expo)++; } // evtl. Exponenten erhöhen
             }
-          clear_loop_msp(ptr mspop 1,len-count-1); // Rest mit Nullen fllen
+          clear_loop_msp(ptr mspop 1,len-count-1); // Rest mit Nullen füllen
          }
          return y;
         }
