@@ -19,7 +19,7 @@ CL_PROVIDE(cl_F_mostneg)
 
 namespace cln {
 
-// Exponent so gro wie mglich, Mantisse 1...1, Vorzeichen -.
+// Exponent so groß wie möglich, Mantisse 1...1, Vorzeichen -.
 
 static const cl_SF most_negative_SF =
 	make_SF(-1,SF_exp_high,bit(SF_mant_len+1)-1);
@@ -43,7 +43,7 @@ inline const cl_LF most_negative_LF (uintC len)
 
 const cl_F most_negative_float (float_format_t f)
 {
-	floatformatcase((uintL)f
+	floatformatcase((uintC)f
 	,	return most_negative_SF;
 	,	return most_negative_FF;
 	,	return most_negative_DF;
