@@ -28,11 +28,11 @@ const cl_SF operator/ (const cl_SF& x1, const cl_SF& x2)
 //   nach Rundung mant1/mant2 >=1/2, <=2*mant1<2.
 //   Bei mant1/mant2 >=1 brauche 16 Nachkommabits,
 //   bei mant1/mant2 <1 brauche 17 Nachkommabits.
-//   Frs Runden: brauche ein Rundungsbit (Rest gibt an, ob exakt).
+//   Fürs Runden: brauche ein Rundungsbit (Rest gibt an, ob exakt).
 //   Brauche daher insgesamt 18 Nachkommabits von mant1/mant2.
 //   Dividiere daher (als Unsigned Integers) 2^18*(2^17*mant1) durch (2^17*mant2).
 //   Falls der Quotient >=2^18 ist, runde die letzten zwei Bits weg und
-//     erhhe den Exponenten um 1.
+//     erhöhe den Exponenten um 1.
 //   Falls der Quotient <2^18 ist, runde das letzte Bit weg. Bei rounding
 //     overflow schiebe um ein weiteres Bit nach rechts, incr. Exponenten.
       // x1,x2 entpacken:
@@ -42,15 +42,15 @@ const cl_SF operator/ (const cl_SF& x1, const cl_SF& x2)
       var cl_signean sign2;
       var sintL exp2;
       var uintL mant2;
-      SF_decode(x2, { cl_error_division_by_0(); }, sign2=,exp2=,mant2=);
+      SF_decode(x2, { throw division_by_0_exception(); }, sign2=,exp2=,mant2=);
       SF_decode(x1, { return x1; }, sign1=,exp1=,mant1=);
       exp1 = exp1 - exp2; // Differenz der Exponenten
       sign1 = sign1 ^ sign2; // Ergebnis-Vorzeichen
-      // Dividiere 2^18*mant1 durch mant2 oder (quivalent)
-      // 2^i*2^18*mant1 durch 2^i*mant2 fr irgendein i mit 0 <= i <= 32-17 :
+      // Dividiere 2^18*mant1 durch mant2 oder (äquivalent)
+      // 2^i*2^18*mant1 durch 2^i*mant2 für irgendein i mit 0 <= i <= 32-17 :
       var uintL mant;
       var uintL rest;
-      // whle i = 32-(SF_mant_len+1), also i+(SF_mant_len+2) = 33.
+      // wähle i = 32-(SF_mant_len+1), also i+(SF_mant_len+2) = 33.
       divu_6432_3232(mant1<<1,0, mant2<<(32-(SF_mant_len+1)), mant=,rest=);
       if (mant >= bit(SF_mant_len+2))
         // Quotient >=2^18 -> 2 Bits wegrunden
