@@ -22,7 +22,7 @@ const cl_SF cl_I_to_SF (const cl_I& x)
 // Merke Vorzeichen von x.
 // x:=(abs x)
 // Exponent:=(integer-length x)
-//   Greife die 18 hchstwertigen Bits heraus (angefhrt von einer 1).
+//   Greife die 18 höchstwertigen Bits heraus (angeführt von einer 1).
 //   Runde das letzte Bit weg:
 //     Bit 0 = 0 -> abrunden,
 //     Bit 0 = 1 und Rest =0 -> round-to-even,
@@ -33,13 +33,13 @@ const cl_SF cl_I_to_SF (const cl_I& x)
       if (eq(x,0)) { return SF_0; }
       var cl_signean sign = -(cl_signean)minusp(x); // Vorzeichen
       var cl_I abs_x = (sign==0 ? x : -x);
-      var uintL exp = integer_length(abs_x); // (integer-length x)
+      var uintC exp = integer_length(abs_x); // (integer-length x)
       // NDS zu |x|>0 bilden:
       var const uintD* MSDptr;
       var uintC len;
-      I_to_NDS_nocopy(abs_x, MSDptr=,len=,,cl_false,);
+      I_to_NDS_nocopy(abs_x, MSDptr=,len=,,false,);
       // MSDptr/len/LSDptr ist die NDS zu x, len>0.
-      // Fhrende Digits holen: Brauche SF_mant_len+1 Bits, dazu intDsize
+      // Führende Digits holen: Brauche SF_mant_len+1 Bits, dazu intDsize
       // Bits (die NDS kann mit bis zu intDsize Nullbits anfangen).
       // Dann werden diese Bits um (exp mod intDsize) nach rechts geschoben.
       var uintD msd = msprefnext(MSDptr); // erstes Digit
@@ -59,15 +59,15 @@ const cl_SF cl_I_to_SF (const cl_I& x)
       --len; ok:
       #if (intDsize==64)
       // Die NDS besteht aus msd, msdd, und len weiteren Digits.
-      // Das hchste in 2^intDsize*msd+msdd gesetzte Bit ist Bit Nummer
+      // Das höchste in 2^intDsize*msd+msdd gesetzte Bit ist Bit Nummer
       // intDsize-1 + (exp mod intDsize).
       var uintL shiftcount = exp % intDsize;
-      var uint64 mant = // fhrende 64 Bits
+      var uint64 mant = // führende 64 Bits
         (shiftcount==0
          ? msdd
          : ((msd << (64-shiftcount)) | (msdd >> shiftcount))
         );
-      // Das hchste in mant gesetzte Bit ist Bit Nummer 63.
+      // Das höchste in mant gesetzte Bit ist Bit Nummer 63.
       if ( ((mant & bit(62-SF_mant_len)) ==0) // Bit 46 =0 -> abrunden
            || ( ((mant & (bit(62-SF_mant_len)-1)) ==0) // Bit 46 =1 und Bits 45..0 =0
                 && ((msdd & (bit(shiftcount)-1)) ==0) // und weitere Bits aus msdd =0
@@ -86,15 +86,15 @@ const cl_SF cl_I_to_SF (const cl_I& x)
         }
       #else
       // Die NDS besteht aus msd, msdd, und len weiteren Digits.
-      // Das hchste in 2^32*msd+msdd gesetzte Bit ist Bit Nummer
+      // Das höchste in 2^32*msd+msdd gesetzte Bit ist Bit Nummer
       // 31 + (exp mod intDsize).
       var uintL shiftcount = exp % intDsize;
-      var uint32 mant = // fhrende 32 Bits
+      var uint32 mant = // führende 32 Bits
         (shiftcount==0
          ? msdd
          : (((uint32)msd << (32-shiftcount)) | (msdd >> shiftcount))
         );
-      // Das hchste in mant gesetzte Bit ist Bit Nummer 31.
+      // Das höchste in mant gesetzte Bit ist Bit Nummer 31.
       if ( ((mant & bit(30-SF_mant_len)) ==0) // Bit 14 =0 -> abrunden
            || ( ((mant & (bit(30-SF_mant_len)-1)) ==0) // Bit 14 =1 und Bits 13..0 =0
                 && ((msdd & (bit(shiftcount)-1)) ==0) // und weitere Bits aus msdd =0
