@@ -20,7 +20,7 @@ const cl_SF cl_RA_to_SF (const cl_RA& x)
 // Methode:
 // x ganz -> klar.
 // x = +/- a/b mit Integers a,b>0:
-//   Seien n,m so gewhlt, da
+//   Seien n,m so gewählt, daß
 //     2^(n-1) <= a < 2^n, 2^(m-1) <= b < 2^m.
 //   Dann ist 2^(n-m-1) < a/b < 2^(n-m+1).
 //   Berechne n=(integer-length a) und m=(integer-length b) und
@@ -40,13 +40,13 @@ const cl_SF cl_RA_to_SF (const cl_RA& x)
       var const cl_I& b = denominator(x); // b
       var cl_signean sign = -(cl_signean)minusp(a); // Vorzeichen
       if (!(sign==0)) { a = -a; } // Betrag nehmen, liefert a
-      var sintL lendiff = (sintL)integer_length(a) // (integer-length a)
-                          - (sintL)integer_length(b); // (integer-length b)
+      var sintC lendiff = (sintC)integer_length(a) // (integer-length a)
+                          - (sintC)integer_length(b); // (integer-length b)
       if (lendiff > SF_exp_high-SF_exp_mid) // Exponent >= n-m > Obergrenze ?
-        { cl_error_floating_point_overflow(); } // -> Overflow
+        { throw floating_point_overflow_exception(); } // -> Overflow
       if (lendiff < SF_exp_low-SF_exp_mid-2) // Exponent <= n-m+2 < Untergrenze ?
         { if (underflow_allowed())
-            { cl_error_floating_point_underflow(); } // -> Underflow
+            { throw floating_point_underflow_exception(); } // -> Underflow
             else
             { return SF_0; }
         }
@@ -61,12 +61,12 @@ const cl_SF cl_RA_to_SF (const cl_RA& x)
         { zaehler = ash(a,(SF_mant_len+2) - lendiff); // (ash a -n+m+18)
           nenner = b; // b
         }
-      // Division zaehler/nenner durchfhren:
+      // Division zaehler/nenner durchführen:
       var cl_I_div_t q_r = cl_divide(zaehler,nenner);
       var cl_I& q = q_r.quotient;
       var cl_I& r = q_r.remainder;
       // 2^17 <= q < 2^19, also ist q Fixnum.
-      var uint32 mant = FN_to_UL(q);
+      var uint32 mant = FN_to_UV(q);
       if (mant >= bit(SF_mant_len+2))
         // 2^18 <= q < 2^19, schiebe um 2 Bits nach rechts
         { var uintL rounding_bits = mant & (bit(2)-1);
