@@ -19,7 +19,7 @@ namespace cln {
 const cosh_sinh_t cosh_sinh (const cl_F& x)
 {
 // Methode:
-// Genauigkeit erhhen,
+// Genauigkeit erhöhen,
 // e := Exponent aus (decode-float x), d := (float-digits x)
 // falls x=0.0 oder e<=(1-d)/2 liefere (1.0,x)
 //   (denn bei e<=(1-d)/2 ist
@@ -33,13 +33,13 @@ const cosh_sinh_t cosh_sinh (const cl_F& x)
 //   (scale-float (+ y (/ y)) -1) und (scale-float (- y (/ y)) -1) bilden.
 // Genauigkeit wieder verringern.
 
-	var sintL e = float_exponent(x);
+	var sintE e = float_exponent(x);
 	if (e < 0) { // Exponent e abtesten
 		// e<0
-		if (zerop(x) || (e <= (1-(sintL)float_digits(x))>>1))
+		if (zerop(x) || (e <= (1-(sintC)float_digits(x))>>1))
 			// e <= (1-d)/2 <==> e <= -ceiling((d-1)/2)
 			return cosh_sinh_t(cl_float(1,x),x);
-		// Rechengenauigkeit erhhen
+		// Rechengenauigkeit erhöhen
 		if (longfloatp(x)) {
 			DeclareType(cl_LF,x);
 			#if 0
@@ -47,14 +47,14 @@ const cosh_sinh_t cosh_sinh (const cl_F& x)
 				var cl_LF xx = extend(x,TheLfloat(x)->len+1);
 				var cl_LF_cosh_sinh_t hyp = cl_coshsinh_ratseries(xx);
 				return cosh_sinh_t(
-					cln/float.hyp.cosh,x),
-					cln/float.hyp.sinh,x)
+					cl_float(hyp.cosh,x),
+					cl_float(hyp.sinh,x)
 				       );
 			} else
 			#endif
 			if (TheLfloat(x)->len >= 585) {
 				// verwende exp(x), schneller als cl_coshsinh_ratseries
-				var cl_LF xx = extend(x,TheLfloat(x)->len+ceiling((uintL)(-e),intDsize));
+				var cl_LF xx = extend(x,TheLfloat(x)->len+ceiling((uintE)(-e),intDsize));
 				var cl_F y = exp(xx);
 				var cl_F y_inv = recip(y);
 				return cosh_sinh_t(
