@@ -16,7 +16,7 @@ namespace cln {
 
 const cl_F pi (float_format_t f)
 {
-	floatformatcase((uintL)f
+	floatformatcase((uintC)f
 	,	return cl_SF_pi;
 	,	return cl_FF_pi;
 	,	return cl_DF_pi;
