@@ -20,8 +20,8 @@ namespace cln {
 const cl_F sin (const cl_F& x)
 {
 // Methode:
-// Genauigkeit erhhen,
-// (q,r) := (round x (float pi/2 x)), so da |r|<=pi/4.
+// Genauigkeit erhöhen,
+// (q,r) := (round x (float pi/2 x)), so daß |r|<=pi/4.
 // y:=(sin(r)/r)^2 errechnen.
 // Falls q gerade:
 //   sin(r) berechnen: r*sqrt(y).
@@ -35,7 +35,7 @@ const cl_F sin (const cl_F& x)
 //     Sonst sqrt(1-r^2*y).
 // Falls q == 2,3 mod 4, Vorzeichenwechsel.
 
-	// Rechengenauigkeit erhhen und durch pi/2 dividieren:
+	// Rechengenauigkeit erhöhen und durch pi/2 dividieren:
 	var cl_F z;
 	var cl_I q;
 	if (longfloatp(x)) {
@@ -61,7 +61,7 @@ const cl_F sin (const cl_F& x)
 					z = -z;
 			} else {
 				// cos(r) berechnen:
-				if (zerop(r) || (float_exponent(r) <= (-(sintL)float_digits(r))>>1))
+				if (zerop(r) || (float_exponent(r) <= (-(sintC)float_digits(r))>>1))
 					z = cl_float(1,x); // cos(r) = 1.0
 				else
 					z = cl_float(sqrt(1 - y),x); // sqrt(1-y)
@@ -77,7 +77,7 @@ const cl_F sin (const cl_F& x)
 			z = cl_float(r*sqrt(y),x);
 		} else {
 			// cos(r) berechnen:
-			if (zerop(r) || (float_exponent(r) <= (-(sintL)float_digits(r))>>1))
+			if (zerop(r) || (float_exponent(r) <= (-(sintC)float_digits(r))>>1))
 				z = cl_float(1,x); // cos(r) = 1.0
 			else
 				z = cl_float(sqrt(1 - square(r)*y),x); // sqrt(1-r^2*y)
