@@ -11,7 +11,7 @@
 
 #include "cln/lfloat.h"
 #include "cln/integer.h"
-#include "cln/abort.h"
+#include "cln/exception.h"
 #include "cl_LF.h"
 
 namespace cln {
@@ -22,13 +22,13 @@ namespace cln {
 // and T = B*Q*S (all integers). On entry N1 < N2.
 // P will not be computed if a NULL pointer is passed.
 
-static void eval_b_series_aux (uintL N1, uintL N2,
+static void eval_b_series_aux (uintC N1, uintC N2,
                                const cl_b_series& args,
                                cl_I* B, cl_I* T)
 {
 	switch (N2 - N1) {
 	case 0:
-		cl_abort(); break;
+		throw runtime_exception(); break;
 	case 1:
 		*B = args.bv[N1];
 		*T = 1;
@@ -58,7 +58,7 @@ static void eval_b_series_aux (uintL N1, uintL N2,
 		break;
 		}
 	default: {
-		var uintL Nm = (N1+N2)/2; // midpoint
+		var uintC Nm = (N1+N2)/2; // midpoint
 		// Compute left part.
 		var cl_I LB, LT;
 		eval_b_series_aux(N1,Nm,args,&LB,&LT);
@@ -74,7 +74,7 @@ static void eval_b_series_aux (uintL N1, uintL N2,
 	}
 }
 
-const cl_LF eval_rational_series (uintL N, const cl_b_series& args, uintC len)
+const cl_LF eval_rational_series (uintC N, const cl_b_series& args, uintC len)
 {
 	if (N==0)
 		return cl_I_to_LF(0,len);
