@@ -4,15 +4,17 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_integer.h"
+#include "cln/integer.h"
 
 
 // Implementation.
 
-#include "cl_integer.h"
+#include "cln/integer.h"
 #include "cl_I.h"
 #include "cl_I_byte.h"
 
+namespace cln {
+
 const cl_I mask_field (const cl_I& n, const cl_byte& b)
 {
       // Methode:
@@ -23,11 +25,11 @@ const cl_I mask_field (const cl_I& n, const cl_byte& b)
       // Falls p <= l :
       //   q:=min(p+s,l).
       //   Extrahiere die Bits p,...,q-1 von n.
-      //   Falls p+s>l und n<0, fge p+s-l Einsenbits an (addiere 2^(p+s)-2^l).
-      var uintL s = b.size;
-      var uintL p = b.position;
-     {var uintL ps = p+s;
-      var uintL l = integer_length(n); // l = (integer-length n)
+      //   Falls p+s>l und n<0, füge p+s-l Einsenbits an (addiere 2^(p+s)-2^l).
+      var uintC s = b.size;
+      var uintC p = b.position;
+     {var uintC ps = p+s;
+      var uintC l = integer_length(n); // l = (integer-length n)
       if (l<=p)
         // l<=p
         if (!minusp(n))
@@ -47,3 +49,5 @@ const cl_I mask_field (const cl_I& n, const cl_byte& b)
             return erg;
      }  }
 }
+
+}  // namespace cln
