@@ -4,7 +4,7 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_integer.h"
+#include "cln/integer.h"
 
 
 // Implementation.
@@ -12,13 +12,15 @@
 #include "cl_I.h"
 #include "cl_DS.h"
 
+namespace cln {
+
 const cl_I minus1 (const cl_I& x)
 {
 	if (fixnump(x))
 	  { // x ist Fixnum
 	    if (x.word != cl_combine(cl_FN_tag,bit(cl_value_len-1)))
 		// bleibt Fixnum: direkt 1 subtrahieren
-		// This assumes cl_value_shift + cl_value_len == cl_word_size.
+		// This assumes cl_value_shift + cl_value_len == cl_pointer_size.
 		{ return cl_I_from_word(x.word - cl_combine(0,1)); }
           }
         // die sichere Methode
@@ -31,3 +33,5 @@ const cl_I minus1 (const cl_I& x)
           return DS_to_I(MSDptr,len); // wieder zum Integer machen
         }
 }
+
+}  // namespace cln
