@@ -31,15 +31,15 @@ const cl_I operator+ (const cl_I& x, const cl_I& y)
         { // x ist Fixnum
           if (fixnump(y))
             { // x,y sind Fixnums
-              #if (cl_value_len < intLsize)
-              return L_to_I( FN_to_L(x) + FN_to_L(y) ); // als 32-Bit-Zahlen addieren
+              #if (cl_value_len < intVsize)
+              return V_to_I( FN_to_V(x) + FN_to_V(y) ); // als intVsize-Bit-Zahlen addieren
               #elif (cl_word_size==64)
               return Q_to_I( FN_to_Q(x) + FN_to_Q(y) ); // als 64-Bit-Zahlen addieren
-              #else // (cl_value_len == intLsize)
-              var sint32 xhi = sign_of(FN_to_L(x));
-              var uint32 xlo = FN_to_L(x);
-              var sint32 yhi = sign_of(FN_to_L(y));
-              var uint32 ylo = FN_to_L(y);
+              #elif (intVsize==32) // && (cl_value_len == intVsize)
+              var sint32 xhi = sign_of(FN_to_V(x));
+              var uint32 xlo = FN_to_V(x);
+              var sint32 yhi = sign_of(FN_to_V(y));
+              var uint32 ylo = FN_to_V(y);
               xhi += yhi;
               xlo += ylo;
               if (xlo < ylo) { xhi += 1; }
@@ -47,13 +47,13 @@ const cl_I operator+ (const cl_I& x, const cl_I& y)
               #endif
             }
             else
-            { // x ist Fixnum, y ist Bignum, also y lnger
+            { // x ist Fixnum, y ist Bignum, also y länger
               #if (intDsize==64)
-              var sint64 x_ = FN_to_L(x); // Wert von x
+              var sint64 x_ = FN_to_V(x); // Wert von x
               #else
-              var sint32 x_ = FN_to_L(x); // Wert von x
+              var sintV x_ = FN_to_V(x); // Wert von x
               #endif
-              if (FN_L_zerop(x,x_)) { return y; } // bei x=0 Ergebnis y
+              if (FN_V_zerop(x,x_)) { return y; } // bei x=0 Ergebnis y
               CL_ALLOCA_STACK;
               BN_to_NDS_1(y, MSDptr=,len=,LSDptr=); // NDS zu y bilden.
               // len>=bn_minlength. len>pFN_maxlength erzwingen:
@@ -68,22 +68,22 @@ const cl_I operator+ (const cl_I& x, const cl_I& y)
                 var uint64 y_new = y_+(uint64)x_;
                 lspref(LSDptr,0) = y_new;
                 #else
-                var uint32 y_ = pFN_maxlength_digits_at(LSDptr);
-                var uint32 y_new = y_+(uint32)x_;
+                var uintV y_ = pFN_maxlength_digits_at(LSDptr);
+                var uintV y_new = y_+(uintV)x_;
                 set_pFN_maxlength_digits_at(LSDptr,y_new);
                 #endif
                 var uintD* midptr = LSDptr lspop pFN_maxlength;
                 if (y_new < y_)
                   { // Carry.
-                    if (!FN_L_minusp(x,x_)) // krzerer Summand war positiv
-                      // Dann ist ein positiver bertrag weiterzutragen
+                    if (!FN_V_minusp(x,x_)) // kürzerer Summand war positiv
+                      // Dann ist ein positiver Übertrag weiterzutragen
                       // (Beispiel: 0002FFFC + 0007 = 00030003)
                       { DS_1_plus(midptr,len-pFN_maxlength); }
                   }
                   else
                   { // Kein Carry.
-                    if (FN_L_minusp(x,x_)) // krzerer Summand war negativ
-                      // Dann ist ein negativer bertrag weiterzutragen
+                    if (FN_V_minusp(x,x_)) // kürzerer Summand war negativ
+                      // Dann ist ein negativer Übertrag weiterzutragen
                       // (Beispiel: 00020003 + FFF5 = 0001FFF8)
                       { DS_minus1_plus(midptr,len-pFN_maxlength); }
               }   }
@@ -93,13 +93,13 @@ const cl_I operator+ (const cl_I& x, const cl_I& y)
         else
         { // x ist Bignum
           if (fixnump(y))
-            { // x ist Bignum, y ist Fixnum, also x lnger
+            { // x ist Bignum, y ist Fixnum, also x länger
               #if (intDsize==64)
-              var sint64 y_ = FN_to_L(y); // Wert von y
+              var sint64 y_ = FN_to_V(y); // Wert von y
               #else
-              var sint32 y_ = FN_to_L(y); // Wert von y
+              var sintV y_ = FN_to_V(y); // Wert von y
               #endif
-              if (FN_L_zerop(y,y_)) { return x; } // bei y=0 Ergebnis x
+              if (FN_V_zerop(y,y_)) { return x; } // bei y=0 Ergebnis x
               CL_ALLOCA_STACK;
               BN_to_NDS_1(x, MSDptr=,len=,LSDptr=); // NDS zu x bilden.
               // len>=bn_minlength. len>pFN_maxlength erzwingen:
@@ -114,22 +114,22 @@ const cl_I operator+ (const cl_I& x, const cl_I& y)
                 var uint64 x_new = x_+(uint64)y_;
                 lspref(LSDptr,0) = x_new;
                 #else
-                var uint32 x_ = pFN_maxlength_digits_at(LSDptr);
-                var uint32 x_new = x_+(uint32)y_;
+                var uintV x_ = pFN_maxlength_digits_at(LSDptr);
+                var uintV x_new = x_+(uintV)y_;
                 set_pFN_maxlength_digits_at(LSDptr,x_new);
                 #endif
                 var uintD* midptr = LSDptr lspop pFN_maxlength;
                 if (x_new < x_)
                   { // Carry.
-                    if (!FN_L_minusp(y,y_)) // krzerer Summand war positiv
-                      // Dann ist ein positiver bertrag weiterzutragen
+                    if (!FN_V_minusp(y,y_)) // kürzerer Summand war positiv
+                      // Dann ist ein positiver Übertrag weiterzutragen
                       // (Beispiel: 0002FFFC + 0007 = 00030003)
                       { DS_1_plus(midptr,len-pFN_maxlength); }
                   }
                   else
                   { // Kein Carry.
-                    if (FN_L_minusp(y,y_)) // krzerer Summand war negativ
-                      // Dann ist ein negativer bertrag weiterzutragen
+                    if (FN_V_minusp(y,y_)) // kürzerer Summand war negativ
+                      // Dann ist ein negativer Übertrag weiterzutragen
                       // (Beispiel: 00020003 + FFF5 = 0001FFF8)
                       { DS_minus1_plus(midptr,len-pFN_maxlength); }
               }   }
@@ -139,41 +139,41 @@ const cl_I operator+ (const cl_I& x, const cl_I& y)
             { // x und y sind Bignums
               CL_ALLOCA_STACK;
               if (TheBignum(x)->length > TheBignum(y)->length)
-                { // x das lngere von beiden.
+                { // x das längere von beiden.
                   BN_to_NDS_1(x, MSDptr=,len=,LSDptr=); // NDS zu x bilden.
                   var const uintD* yMSDptr;
                   var uintC ylen;
                   var const uintD* yLSDptr;
                   BN_to_NDS_nocopy(y, yMSDptr=,ylen=,yLSDptr=); // NDS zu y bilden.
-                  // yMSDptr/ylen/yLSDptr bilden die DS des krzeren Arguments y.
+                  // yMSDptr/ylen/yLSDptr bilden die DS des kürzeren Arguments y.
                   // Es ist len>ylen.
                   // addieren:
                   { var uintD* midptr = LSDptr lspop ylen;
                     var uintD carry = addto_loop_lsp(yLSDptr,LSDptr,ylen);
                     if (carry)
                       { // Carry.
-                        if ((sintD)mspref(yMSDptr,0) >=0) // krzerer Summand war positiv
-                          // Dann ist ein positiver bertrag weiterzutragen
+                        if ((sintD)mspref(yMSDptr,0) >=0) // kürzerer Summand war positiv
+                          // Dann ist ein positiver Übertrag weiterzutragen
                           // (Beispiel: 0002FFFC + 0007 = 00030003)
                           { DS_1_plus(midptr,len-ylen); }
                       }
                       else
                       { // Kein Carry.
-                        if ((sintD)mspref(yMSDptr,0) <0) // krzerer Summand war negativ
-                          // Dann ist ein negativer bertrag weiterzutragen
+                        if ((sintD)mspref(yMSDptr,0) <0) // kürzerer Summand war negativ
+                          // Dann ist ein negativer Übertrag weiterzutragen
                           // (Beispiel: 00020003 + FFF5 = 0001FFF8)
                           { DS_minus1_plus(midptr,len-ylen); }
                   }   }
                   return DS_to_I(MSDptr,len); // DS wieder zum Integer machen
                 }
                 else
-                { // y das lngere von beiden.
+                { // y das längere von beiden.
                   BN_to_NDS_1(y, MSDptr=,len=,LSDptr=); // NDS zu y bilden.
                   var const uintD* xMSDptr;
                   var uintC xlen;
                   var const uintD* xLSDptr;
                   BN_to_NDS_nocopy(x, xMSDptr=,xlen=,xLSDptr=); // NDS zu x bilden.
-                  // xMSDptr/xlen/xLSDptr bilden die DS des krzeren Arguments x.
+                  // xMSDptr/xlen/xLSDptr bilden die DS des kürzeren Arguments x.
                   // len>xlen erzwingen:
                   if (len==xlen)
                     { var sintD sign = sign_of_sintD(mspref(MSDptr,0));
@@ -184,15 +184,15 @@ const cl_I operator+ (const cl_I& x, const cl_I& y)
                     var uintD carry = addto_loop_lsp(xLSDptr,LSDptr,xlen);
                     if (carry)
                       { // Carry.
-                        if ((sintD)mspref(xMSDptr,0) >=0) // krzerer Summand war positiv
-                          // Dann ist ein positiver bertrag weiterzutragen
+                        if ((sintD)mspref(xMSDptr,0) >=0) // kürzerer Summand war positiv
+                          // Dann ist ein positiver Übertrag weiterzutragen
                           // (Beispiel: 0002FFFC + 0007 = 00030003)
                           { DS_1_plus(midptr,len-xlen); }
                       }
                       else
                       { // Kein Carry.
-                        if ((sintD)mspref(xMSDptr,0) <0) // krzerer Summand war negativ
-                          // Dann ist ein negativer bertrag weiterzutragen
+                        if ((sintD)mspref(xMSDptr,0) <0) // kürzerer Summand war negativ
+                          // Dann ist ein negativer Übertrag weiterzutragen
                           // (Beispiel: 00020003 + FFF5 = 0001FFF8)
                           { DS_minus1_plus(midptr,len-xlen); }
                   }   }
