@@ -17,14 +17,14 @@
 
 namespace cln {
 
-cl_boolean plusp (const cl_I& x)
+bool plusp (const cl_I& x)
 {
 	if (inline_minusp(x))
-		return cl_false; // x<0 -> nein
+		return false; // x<0 -> nein
 	elif (inline_zerop(x))
-		return cl_false; // x=0 -> nein
+		return false; // x=0 -> nein
 	else
-		return cl_true; // sonst ist x>0.
+		return true; // sonst ist x>0.
 }
 
 }  // namespace cln
