@@ -16,12 +16,12 @@
 
 namespace cln {
 
-#define GCD_ALGO 3  // 1: binr, 2: Schulmethode, 3: Lehmer
+#define GCD_ALGO 3  // 1: binär, 2: Schulmethode, 3: Lehmer
 
 
 #if (GCD_ALGO == 1)
 
-// binre Methode:
+// binäre Methode:
 // (gcd a b) :==
 // b=0 --> (abs a)
 // a=0 --> (abs b)
@@ -147,14 +147,14 @@ namespace cln {
       if (eq(b,1)) { return 1; } // b=1 -> 1
       if (eq(b,0)) { return abs(a); } // b=0 -> (abs a)
       if (eq(a,0)) { return abs(b); } // a=0 -> (abs b)
-      // Betrge nehmen:
+      // Beträge nehmen:
      {var cl_I abs_a = abs(a);
       var cl_I abs_b = abs(b);
       var cl_I& a = abs_a;
       var cl_I& b = abs_b;
       if (fixnump(a) && fixnump(b)) // ggT zweier Fixnums >0
         { // bleibt Fixnum, da (gcd a b) <= (min a b)
-          return L_to_FN(gcd(FN_to_UL(a),FN_to_UL(b)));
+          return V_to_FN(gcd(FN_to_UV(a),FN_to_UV(b)));
         }
       { var cl_signean vergleich = compare(a,b);
         if (vergleich == 0) { return a; } // a=b -> fertig
@@ -188,16 +188,16 @@ namespace cln {
 // Falls (- (integer-length a) (integer-length b)) >= intDsize/2,
 //   lohnt sich eine Division: (a,b) := (b , a mod b). Falls b=0: return a.
 // Falls dagegen 0 <= (- (integer-length a) (integer-length b)) < intDsize/2,
-//   seien a' die fhrenden intDsize Bits von a
+//   seien a' die führenden intDsize Bits von a
 //   (2^(intDsize-1) <= a' < 2^intDsize) und b' die entsprechenden Bits von b
 //   (2^(intDsize/2) <= b' <= a' < 2^intDsize).
-//   Rechne den Euklid-Algorithmus mit Beifaktoren fr ALLE Zahlen (a,b) aus,
-//   die mit a' bzw. b' anfangen; das liefert x1,y1,x2,y2, so da
+//   Rechne den Euklid-Algorithmus mit Beifaktoren für ALLE Zahlen (a,b) aus,
+//   die mit a' bzw. b' anfangen; das liefert x1,y1,x2,y2, so daß
 //   ggT(a,b) = ggT(x1*a-y1*b,-x2*a+y2*b) und x1*a-y1*b>=0,-x2*a+y2*b>=0.
 //   Genauer: Mit offensichtlicher Skalierung betrachten wir
 //            a als beliebiges Element des Intervalls [a',a'+1) und
 //            b als beliebiges Element des Intervalls [b',b'+1) und
-//            fhren den Euklid-Algorithmus schrittweise durch:
+//            führen den Euklid-Algorithmus schrittweise durch:
 //            (x1,y1,z1) := (1,0,a'), (x2,y2,z2) := (0,1,b'),
 //            Schleife:
 //            {Hier x1*a'-y1*b'=z1, x1*a-y1*b in [z1-y1,z1+x1), z1-y1>=0, z1>0,
@@ -207,7 +207,7 @@ namespace cln {
 //              (x1,y1,z1) := (x1+x2,y1+y2,z1-z2), goto Schleife.
 //            Falls z2-x2>=z1+x1:
 //              (x2,y2,z2) := (x2+x1,y2+y1,z2-z1), goto Schleife.
-//            Sonst mu man abbrechen.
+//            Sonst muß man abbrechen.
 //            {Zu den Schleifeninvarianten:
 //             1. Die Gleichungen x1*a'-y1*b'=z1, -x2*a'+y2*b'=z2,
 //                x1*y2-x2*y1=1, x1*z2+x2*z1=b', y1*z2+y2*z1=a' mit Induktion.
@@ -221,22 +221,22 @@ namespace cln {
 //             7. Die Ungleichung max(z1,z2) <= a' mit Induktion.
 //             8. Die Ungleichung x1+x2 <= x1*z2+x2*z1 = b',
 //                die Ungleichung y1+y2 <= y1*z2+y2*z1 = a'.
-//             Damit bleiben alle Gren im Intervall [0,beta), kein berlauf.
+//             Damit bleiben alle Größen im Intervall [0,beta), kein Überlauf.
 //             9. Die Ungleichungen z1+x1<=beta, z2+y2<=beta mit Induktion.
 //             10. x1*a-y1*b in (z1-y1,z1+x1) (bzw. [z1,z1+x1) bei y1=0),
 //                -x2*a+y2*b in (z2-x2,z2+y2) (bzw. [z2,z2+y2) bei x2=0),
 //                da a in a'+[0,1) und b in b'+[0,1).
 //                Jedenfalls 0 < x1*a-y1*b < z1+x1 <= x2*z1+x1*z2 = b' falls x2>0,
 //                und        0 < -x2*a+y2*b < z2+y2 <= y1*z2+y2*z1 = a' falls y1>0.}
-//            Man kann natrlich auch mehrere Subtraktionsschritte auf einmal
-//            durchfhren:
+//            Man kann natürlich auch mehrere Subtraktionsschritte auf einmal
+//            durchführen:
 //            Falls q := floor((z1-y1)/(z2+y2)) > 0 :
 //              (x1,y1,z1) := (x1+q*x2,y1+q*y2,z1-q*z2), goto Schleife.
 //            Falls q := floor((z2-x2)/(z1+x1)) > 0 :
 //              (x2,y2,z2) := (x2+q*x1,y2+q*y1,z2-q*z1), goto Schleife.
-//            {Am Schlu gilt -(x1+x2) < z1-z2 < y1+y2 und daher
+//            {Am Schluß gilt -(x1+x2) < z1-z2 < y1+y2 und daher
 //             z2-x2 <= b'/(x1+x2) < z1+x1, z1-y1 <= a'/(y1+y2) < z2+y2,
-//             und - unter Bercksichtigung von x1*y2-x2*y1=1 -
+//             und - unter Berücksichtigung von x1*y2-x2*y1=1 -
 //             z1-y1 <= b'/(x1+x2) < z2+y2, z2-x2 <= a'/(y1+y2) < z1+x1,
 //             also  max(z1-y1,z2-x2) <= min(b'/(x1+x2),a'/(y1+y2))
 //                          <= max(b'/(x1+x2),a'/(y1+y2)) < min(z1+x1,z2+y2).}
@@ -296,11 +296,11 @@ namespace cln {
       if (eq(b,0)) { return abs(a); } // b=0 -> (abs a)
       if (eq(a,0)) { return abs(b); } // a=0 -> (abs b)
       if (fixnump(a) && fixnump(b)) // ggT zweier Fixnums /=0
-        { var sintL a_ = FN_to_L(a);
+        { var sintV a_ = FN_to_V(a);
           if (a_ < 0) { a_ = -a_; }
-          var sintL b_ = FN_to_L(b);
+          var sintV b_ = FN_to_V(b);
           if (b_ < 0) { b_ = -b_; }
-          return UL_to_I(gcd((uint32)a_,(uint32)b_));
+          return UV_to_I(gcd((uintV)a_,(uintV)b_));
         }
       CL_ALLOCA_STACK;
       var uintD* a_MSDptr;
@@ -320,11 +320,11 @@ namespace cln {
       I_abs_to_NUDS(b); // (abs b) als NUDS erzeugen
       // Jetzt ist a = a_MSDptr/a_len/a_LSDptr, b = b_MSDptr/b_len/b_LSDptr,
       // beides NUDS, und a_len>0, b_len>0.
-      // Platz fr zwei Rechenregister besorgen, mit je max(a_len,b_len)+1 Digits:
-      {var uintD* divroomptr; // Platz fr Divisionsergebnis
+      // Platz für zwei Rechenregister besorgen, mit je max(a_len,b_len)+1 Digits:
+      {var uintD* divroomptr; // Platz für Divisionsergebnis
        var uintD* c_LSDptr;
        var uintD* d_LSDptr;
-       {var uintL c_len = (uintL)(a_len>=b_len ? a_len : b_len) + 1;
+       {var uintC c_len = (a_len>=b_len ? a_len : b_len) + 1;
         num_stack_alloc(c_len,divroomptr=,c_LSDptr=);
         num_stack_alloc(c_len,,d_LSDptr=);
         // Jetzt ist ../c_len/c_LSDptr, ../c_len/d_LSDptr frei.
@@ -344,7 +344,7 @@ namespace cln {
            swap(uintD*, a_LSDptr,b_LSDptr);
            a_greater_b:
            // Hier a>b>0, beides NUDS.
-           if (b_len==1) // Beschleunigung eines hufigen Falles
+           if (b_len==1) // Beschleunigung eines häufigen Falles
              { var uintD b0 = mspref(b_MSDptr,0);
                if (b0==1)
                   // a>b=1 -> Ergebnis 1.
@@ -361,21 +361,21 @@ namespace cln {
                return UD_to_I(gcdD(a0,b0));
              }
            // Entscheidung, ob Division oder Linearkombination:
-           { var uintD a_msd; // fhrende intDsize Bits von a
+           { var uintD a_msd; // führende intDsize Bits von a
              var uintD b_msd; // entsprechende Bits von b
              #if DOUBLE_SPEED
-             var uintD a_nsd; // nchste intDsize Bits von a
+             var uintD a_nsd; // nächste intDsize Bits von a
              var uintD b_nsd; // entsprechende Bits von b
              #endif
-             { var uintC len_diff = a_len-b_len; // Lngendifferenz
-               if (len_diff > 1) goto divide; // >=2 -> Bitlngendifferenz>intDsize -> dividieren
+             { var uintC len_diff = a_len-b_len; // Längendifferenz
+               if (len_diff > 1) goto divide; // >=2 -> Bitlängendifferenz>intDsize -> dividieren
                #define bitlendiff_limit  (intDsize/2) // sollte >0,<intDsize sein
               {var uintC a_msd_size;
-               a_msd = mspref(a_MSDptr,0); // fhrendes Digit von a
-               integerlengthD(a_msd,a_msd_size=); // dessen Bit-Lnge (>0,<=intDsize) berechnen
+               a_msd = mspref(a_MSDptr,0); // führendes Digit von a
+               integerlengthD(a_msd,a_msd_size=); // dessen Bit-Länge (>0,<=intDsize) berechnen
                b_msd = mspref(b_MSDptr,0);
                #if HAVE_DD
-               {var uintDD b_msdd = // 2 fhrende Digits von b
+               {var uintDD b_msdd = // 2 führende Digits von b
                   (len_diff==0
                    ? highlowDD(b_msd, mspref(b_MSDptr,1))
                    : (uintDD)b_msd
@@ -387,7 +387,7 @@ namespace cln {
                 b_nsd = lowD(highlowDD(lowD(b_msdd), (b_len<=2-len_diff ? 0 : mspref(b_MSDptr,2-len_diff))) >> a_msd_size);
                 #endif
                }
-               {var uintDD a_msdd = // 2 fhrende Digits von a
+               {var uintDD a_msdd = // 2 führende Digits von a
                   highlowDD(a_msd, mspref(a_MSDptr,1));
                 a_msd = lowD(a_msdd >> a_msd_size);
                 #if DOUBLE_SPEED
@@ -402,9 +402,9 @@ namespace cln {
                        && (b_msd < (uintD)bit(a_msd_size-bitlendiff_limit))
                       )
                      goto divide;
-                   // Entscheidung fr Linearkombination ist gefallen.
-                   // a_msd und b_msd so erweitern, da a_msd die fhrenden
-                   // intDsize Bits von a enthlt:
+                   // Entscheidung für Linearkombination ist gefallen.
+                   // a_msd und b_msd so erweitern, daß a_msd die führenden
+                   // intDsize Bits von a enthält:
                   {var uintC shiftcount = intDsize-a_msd_size; // Shiftcount nach links (>=0, <intDsize)
                    if (shiftcount>0)
                      { a_msd = a_msd << shiftcount;
@@ -432,9 +432,9 @@ namespace cln {
                        || (b_msd < (uintD)bit(a_msd_size+intDsize-bitlendiff_limit))
                       )
                      goto divide;
-                   // Entscheidung fr Linearkombination ist gefallen.
-                   // a_msd und b_msd so erweitern, da a_msd die fhrenden
-                   // intDsize Bits von a enthlt:
+                   // Entscheidung für Linearkombination ist gefallen.
+                   // a_msd und b_msd so erweitern, daß a_msd die führenden
+                   // intDsize Bits von a enthält:
                    // 0 < a_msd_size < b_msd_size + bitlendiff_limit - intDsize <= bitlendiff_limit < intDsize.
                    a_msd = (a_msd << (intDsize-a_msd_size)) | (mspref(a_MSDptr,1) >> a_msd_size);
                    #if DOUBLE_SPEED
@@ -449,7 +449,7 @@ namespace cln {
                #undef bitlendiff_limit
              }}
              // Nun ist a_msd = a' > b' = b_msd.
-             { // Euklid-Algorithmus auf den fhrenden Digits durchfhren:
+             { // Euklid-Algorithmus auf den führenden Digits durchführen:
                var partial_gcd_result likobi;
                #if DOUBLE_SPEED
                if (a_len >= cl_gcd_double_threshold)
@@ -467,14 +467,14 @@ namespace cln {
                if (likobi.x2==0)
                  { // Ersetze (a,b) := (a-y1*b,b).
                    if (likobi.y1==1) goto subtract; // einfacherer Fall
-                   // Dazu evtl. a um 1 Digit erweitern, so da a_len=b_len+1:
+                   // Dazu evtl. a um 1 Digit erweitern, so daß a_len=b_len+1:
                    if (a_len == b_len) { lsprefnext(a_MSDptr) = 0; a_len++; }
                    // und y1*b von a subtrahieren:
                    mspref(a_MSDptr,0) -= mulusub_loop_lsp(likobi.y1,b_LSDptr,a_LSDptr,b_len);
                  }
                  else
                  { // Ersetze (a,b) := (x1*a-y1*b,-x2*a+y2*b).
-                   // Dazu evtl. b um 1 Digit erweitern, so da a_len=b_len:
+                   // Dazu evtl. b um 1 Digit erweitern, so daß a_len=b_len:
                    if (!(a_len==b_len)) { lsprefnext(b_MSDptr) = 0; b_len++; }
                    // c := x1*a-y1*b bilden:
                    mulu_loop_lsp(likobi.x1,a_LSDptr,c_LSDptr,a_len);
@@ -484,7 +484,7 @@ namespace cln {
                    mulu_loop_lsp(likobi.y2,b_LSDptr,d_LSDptr,a_len);
                    /* lspref(d_LSDptr,a_len) -= */
                      mulusub_loop_lsp(likobi.x2,a_LSDptr,d_LSDptr,a_len);
-                   // Wir wissen, da 0 < c < b und 0 < d < a. Daher mten
+                   // Wir wissen, daß 0 < c < b und 0 < d < a. Daher müßten
                    // lspref(c_LSDptr,a_len) und lspref(d_LSDptr,a_len) =0 sein.
                    // a := c und b := d kopieren:
                    copy_loop_lsp(c_LSDptr,a_LSDptr,a_len);
@@ -492,16 +492,16 @@ namespace cln {
                    // b normalisieren:
                    while (mspref(b_MSDptr,0)==0) { msshrink(b_MSDptr); b_len--; }
              }   }
-             if (cl_false)
+             if (false)
                { subtract: // Ersetze (a,b) := (a-b,b).
                  if (!( subfrom_loop_lsp(b_LSDptr,a_LSDptr,b_len) ==0))
-                   // bertrag nach b_len Stellen, mu also a_len=b_len+1 sein.
+                   // Übertrag nach b_len Stellen, muß also a_len=b_len+1 sein.
                    { mspref(a_MSDptr,0) -= 1; }
                }
              // a normalisieren:
              while (mspref(a_MSDptr,0)==0) { msshrink(a_MSDptr); a_len--; }
            }
-           if (cl_false)
+           if (false)
              { divide: // Ersetze (a,b) := (b , a mod b).
               {var uintD* old_a_LSDptr = a_LSDptr;
                var DS q;
@@ -509,7 +509,7 @@ namespace cln {
                cl_UDS_divide(a_MSDptr,a_len,a_LSDptr,b_MSDptr,b_len,b_LSDptr, divroomptr, &q,&r);
                a_MSDptr = b_MSDptr; a_len = b_len; a_LSDptr = b_LSDptr; // a := b
                b_len = r.len; if (b_len==0) break; // b=0 -> fertig
-               b_LSDptr = old_a_LSDptr; // b bernimmt den vorherigen Platz von a
+               b_LSDptr = old_a_LSDptr; // b übernimmt den vorherigen Platz von a
                b_MSDptr = copy_loop_lsp(r.LSDptr,b_LSDptr,b_len); // b := r kopieren
                goto a_greater_b; // Nun ist a>b>0
              }}
