@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_integer.h"
+#include "cln/integer.h"
 
 
 // Implementation.
 
 #include "cl_I.h"
 
+namespace cln {
+
 const cl_I lcm (const cl_I& a, const cl_I& b)
 {
 // Methode:
@@ -20,7 +22,7 @@ const cl_I lcm (const cl_I& a, const cl_I& b)
 // Falls g=1, Ergebnis a*b, sonst Ergebnis (a/g)*b.
       if (eq(a,0)) { return 0; }
       if (eq(b,0)) { return 0; }
-      // Betrge nehmen:
+      // Beträge nehmen:
      {var cl_I abs_a = abs(a);
       var cl_I abs_b = abs(b);
       var cl_I& a = abs_a;
@@ -30,3 +32,5 @@ const cl_I lcm (const cl_I& a, const cl_I& b)
       return a*b;
      }
 }
+
+}  // namespace cln
