@@ -4,13 +4,15 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_integer.h"
+#include "cln/integer.h"
 
 
 // Implementation.
 
 #include "cl_I.h"
 
+namespace cln {
+
 const cl_I abs (const cl_I& x)
 {
 	// Methode:
@@ -20,3 +22,5 @@ const cl_I abs (const cl_I& x)
 	else
 		return x;
 }
+
+}  // namespace cln
