@@ -29,42 +29,70 @@ namespace cln {
   //     two in factorial(m).
 
 static cl_I const doublefakul_table [] = {
-        L_to_FN(1),
-        L_to_FN(1UL),
-        L_to_FN(1UL*2),
-        L_to_FN(1UL*3),
+        1,
+        1UL,
+        1UL*2,
+        1UL*3,
         #if (cl_value_len>=5)
-        L_to_FN(1UL*2*4),
-        L_to_FN(1UL*3*5),
+        1UL*2*4,
+        1UL*3*5,
         #if (cl_value_len>=7)
-        L_to_FN(1UL*2*4*6),
+        1UL*2*4*6,
         #if (cl_value_len>=8)
-        L_to_FN(1UL*3*5*7),
+        1UL*3*5*7,
         #if (cl_value_len>=10)
-        L_to_FN(1UL*2*4*6*8),
+        1UL*2*4*6*8,
         #if (cl_value_len>=11)
-        L_to_FN(1UL*3*5*7*9),
+        1UL*3*5*7*9,
         #if (cl_value_len>=13)
-        L_to_FN(1UL*2*4*6*8*10),
+        1UL*2*4*6*8*10,
         #if (cl_value_len>=15)
-        L_to_FN(1UL*3*5*7*9*11),
+        1UL*3*5*7*9*11,
         #if (cl_value_len>=17)
-        L_to_FN(1UL*2*4*6*8*10*12),
+        1UL*2*4*6*8*10*12,
         #if (cl_value_len>=19)
-        L_to_FN(1UL*3*5*7*9*11*13),
+        1UL*3*5*7*9*11*13,
         #if (cl_value_len>=21)
-        L_to_FN(1UL*2*4*6*8*10*12*14),
+        1UL*2*4*6*8*10*12*14,
         #if (cl_value_len>=22)
-        L_to_FN(1UL*3*5*7*9*11*13*15),
+        1UL*3*5*7*9*11*13*15,
         #if (cl_value_len>=25)
-        L_to_FN(1UL*2*4*6*8*10*12*14*16),
+        1UL*2*4*6*8*10*12*14*16,
         #if (cl_value_len>=27)
-        L_to_FN(1UL*3*5*7*9*11*13*15*17),
+        1UL*3*5*7*9*11*13*15*17,
         #if (cl_value_len>=29)
-        L_to_FN(1UL*2*4*6*8*10*12*14*16*18),
+        1UL*2*4*6*8*10*12*14*16*18,
         #if (cl_value_len>=31)
-        L_to_FN(1UL*3*5*7*9*11*13*15*17*19),
+        1UL*3*5*7*9*11*13*15*17*19,
         #if (cl_value_len>=33)
+        1UL*2*4*6*8*10*12*14*16*18*20,
+        #if (cl_value_len>=35)
+        1UL*3*5*7*9*11*13*15*17*19*21,
+        #if (cl_value_len>=38)
+        1UL*2*4*6*8*10*12*14*16*18*20*22,
+        #if (cl_value_len>=40)
+        1UL*3*5*7*9*11*13*15*17*19*21*23,
+        #if (cl_value_len>=42)
+        1UL*2*4*6*8*10*12*14*16*18*20*22*24,
+        #if (cl_value_len>=44)
+        1UL*3*5*7*9*11*13*15*17*19*21*23*25,
+        #if (cl_value_len>=47)
+        1UL*2*4*6*8*10*12*14*16*18*20*22*24*26,
+        #if (cl_value_len>=49)
+        1UL*3*5*7*9*11*13*15*17*19*21*23*25*27,
+        #if (cl_value_len>=52)
+        1UL*2*4*6*8*10*12*14*16*18*20*22*24*26*28,
+        #if (cl_value_len>=54)
+        1UL*3*5*7*9*11*13*15*17*19*21*23*25*27*29,
+        #if (cl_value_len>=57)
+        1UL*2*4*6*8*10*12*14*16*18*20*22*24*26*28*30,
+        #if (cl_value_len>=59)
+        1UL*3*5*7*9*11*13*15*17*19*21*23*25*27*29*31,
+        #if (cl_value_len>=62)
+        1UL*2*4*6*8*10*12*14*16*18*20*22*24*26*28*30*32,
+        #if (cl_value_len>=64)
+        1UL*3*5*7*9*11*13*15*17*19*21*23*25*27*29*31*33,
+        #if (cl_value_len>=67)
         ...
         #endif
         #endif
@@ -82,6 +110,20 @@ static cl_I const doublefakul_table [] = {
         #endif
         #endif
         #endif
+        #endif
+        #endif
+        #endif
+        #endif
+        #endif
+        #endif
+        #endif
+        #endif
+        #endif
+        #endif
+        #endif
+        #endif
+        #endif
+        #endif
 };
 
 const cl_I doublefactorial (uintL n) // assume n >= 0 small
@@ -95,9 +137,9 @@ const cl_I doublefactorial (uintL n) // assume n >= 0 small
             var uintL A = n;
             var uintL B = n; // obere Intervallgrenze floor(n/2^(k-1))
             loop
-              { // 'A' enthlt floor(n/2^(k-1)).
+              { // 'A' enthält floor(n/2^(k-1)).
                 A = A >> 1; // untere Grenze floor(n/2^k)
-                // 'A' enthlt floor(n/2^k).
+                // 'A' enthält floor(n/2^k).
                 // Bilde Teilprodukt prod(A < i <= B & oddp(i), i)
                 //       = prod(floor((A-1)/2) < i <= floor((B-1)/2), 2*i+1)
                 // wobei B = floor(n/2^(k-1)), A = floor(n/2^k) = floor(B/2).
@@ -117,9 +159,9 @@ const cl_I doublefactorial (uintL n) // assume n >= 0 small
             var uintL A = m;
             var uintL B = m; // obere Intervallgrenze floor(m/2^(k-1))
             loop
-              { // 'A' enthlt floor(m/2^(k-1)).
+              { // 'A' enthält floor(m/2^(k-1)).
                 A = A >> 1; // untere Grenze floor(m/2^k)
-                // 'A' enthlt floor(m/2^k).
+                // 'A' enthält floor(m/2^k).
                 // Bilde Teilprodukt prod(A < i <= B & oddp(i), i)
                 //       = prod(floor((A-1)/2) < i <= floor((B-1)/2), 2*i+1)
                 // wobei B = floor(m/2^(k-1)), A = floor(m/2^k) = floor(B/2).
