@@ -21,8 +21,8 @@ const cl_RA read_rational (unsigned int base, cl_signean sign, const char * stri
 	var cl_I den = // Nenner
 	  digits_to_I(&string[index3_1],index2-index3_1,(uintD)base);
 	if (zerop(den)) // Division durch 0 abfangen
-		{ cl_error_division_by_0(); }
-	var cl_I num = // Zhler
+		{ throw division_by_0_exception(); }
+	var cl_I num = // Zähler
 	  digits_to_I(&string[index1],index3-index1,(uintD)base);
 	if (!(sign == 0))
 		num = -num; // incl. Vorzeichen
