@@ -4,15 +4,17 @@
 #include "cl_sysdep.h"
 
 // Specification.
-#include "cl_real.h"
+#include "cln/real.h"
 
 
 // Implementation.
 
 #include "cl_R.h"
-#include "cl_rational.h"
+#include "cln/rational.h"
 #include "cl_R_div_t.h"
 
+namespace cln {
+
 const cl_R_div_t truncate2 (const cl_R& x, const cl_R& y)
 {
 // Methode:
@@ -29,3 +31,5 @@ const cl_R_div_t truncate2 (const cl_R& x, const cl_R& y)
 	var cl_R& r = q_r.remainder;
 	return cl_R_div_t(q,y*r);
 }
+
+}  // namespace cln
