@@ -10,12 +10,13 @@
 // Implementation.
 
 #include "cl_R.h"
+#define minusp minusp_inline
 #include "cl_RA.h"
 #include "cl_I.h"
+#undef minusp
 #include "cl_F.h"
 
-#undef MAYBE_INLINE
-#define MAYBE_INLINE inline
+#include "cl_inline.h"
 #include "cl_SF_minusp.cc"
 #include "cl_FF_minusp.cc"
 #include "cl_DF_minusp.cc"
@@ -23,11 +24,11 @@
 
 namespace cln {
 
-cl_boolean minusp (const cl_R& x)
+bool CL_FLATTEN minusp (const cl_R& x)
 #if 0
 GEN_R_OP1_2(x, minusp, return)
 #else // fully inlined, faster
-GEN_R_OP1_7(x, minusp, return)
+GEN_R_OP1_7(x, minusp_inline, return)
 #endif
 
 }  // namespace cln
